@@ -4,6 +4,7 @@ from pyramid_rest.server import Server
 from pyramid_rest.decorators import registerResource
 from pprint import pprint
 from pyramid_rest.logger import Logger
+from pyramid_rest.events import EventManager
 
 
 
@@ -35,4 +36,5 @@ class App:
         pprint(self.logger.__dict__)
         self.logger.app.info("Logger initialized")
         self.server = Server(self)
-        self.logger.app.info("Server initialized")
\ No newline at end of file
+        self.logger.app.info("Server initialized")
+        EventManager().trigger("after-app-initialize", self)
\ No newline at end of file
