@@ -19,7 +19,8 @@ class Logger:
                        'view',
                        'files',
                        'models',
-                       'events']
+                       'events',
+                       'request_manager']
     def __init__(self, app = None):
         for name in self.ALLOWED_LOGGERS:
             setattr(self, name, logging.getLogger(name))
