@@ -1,6 +1,7 @@
 #-*- coding: utf-8 -*-
 from pyramid_rest.helpers import singletone
 from pyramid_rest.view import View
+from pyramid_rest.events import EventManager
 
 class Server:
     def __init__(self, app):
@@ -15,8 +16,10 @@ class Server:
             :param url: URL
             :param view: функция-представление. Вызывается при обращении к роуту и принимает объект pyramid-request
         """
+        EventManager().trigger("before-add-route", self, name, url, view)
         self.app.config.add_route(name, url, view = View(self.app, view), renderer = "json")
         self.app.logger.server.info("Added route with name: %s; url: %s", name, url)
+        EventManager().trigger("after-add-route", self, name, url, view)
     
         
     
\ No newline at end of file
