@@ -1,5 +1,7 @@
 #-*- coding: utf-8 -*-
 from pyramid_rest.exceptions import ExceptionInterface
+from pyramid_rest.events import EventManager
+from pyramid_rest.request import Request
 
 
 class View:
@@ -20,9 +22,11 @@ class View:
         
         
     def __call__(self, pyramid_request):
+        request = Request(pyramid_request)
+        EventManager().trigger("before-request", self, request)
         try:
-            response = self.view(pyramid_request)
+            response = self.view(request)
         except ExceptionInterface as x:
-            return x.serialize(pyramid_request)
-        
+            response = x.serialize(request)
+        EventManager().trigger("before-response", self, request, response)
         return response
\ No newline at end of file
